TokenGrantedEvent class

Emitted when tokens are released back to the budget, making them available for other pools.

Inheritance

Constructors

TokenGrantedEvent({required String poolId, required int grantedCount})
Creates a token granted event.

Properties

grantedCount int
The number of tokens that were released (now available).
final
hashCode int
The hash code for this object.
no setterinherited
poolId String
The pool that this token event relates to.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
The wall-clock time this event was created, in milliseconds since epoch.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited