EmergencyFlushEvent class
Emitted when an emergency memory flush disposes all non-primary players.
Constructors
- EmergencyFlushEvent({required int? survivorEntryId, required int disposedCount})
- Creates an emergency flush event.
Properties
- disposedCount → int
-
The number of player instances that were disposed during the flush.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- survivorEntryId → int?
-
The entry ID of the surviving (primary) player, or
nullif everything was disposed.final - timestamp → int
-
The wall-clock time this event was created, in milliseconds since epoch.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited