ResolutionHint enum
Hint about expected video resolution for memory estimation.
Values
- hd720 → const ResolutionHint
-
720p (1280x720) — ~12 MB estimated memory per player.
- hd1080 → const ResolutionHint
-
1080p (1920x1080) — ~24 MB estimated memory per player.
- uhd4k → const ResolutionHint
-
4K UHD (3840x2160) — ~96 MB estimated memory per player.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ResolutionHint> - A constant List of the values in this enum, in order of their declaration.