TokenEvent class sealed
Base class for all token-related events in the decoder budget system.
Token events are emitted by DecoderBudget implementations when tokens are requested, granted (released back), or revoked.
- Inheritance
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- poolId → String
-
The pool that this token event relates to.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → int
-
The wall-clock time this event was created, in milliseconds since epoch.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited